#! /bin/bash

# MSP430 firmware version
REQ_VERSION=1.3

find_mtdnum() {
    # mtdname -> mtd number
    local mtdname=$1
    local mtd=`cat /proc/mtd | grep -F \"$mtdname\" | cut -d ':' -f 1`
    local mtdnumber="${mtd#mtd}"

    echo $mtdnumber
}

write_to_mtd() {
    # mountpoint, kind, area, pre-erase
    local dir=$1
    local kind=$2
    local area=$3
    local erase=$4

    local mtdname=

    if [ "$area" = "0" ] || [ "$area" = "1" ]; then
        mtdname=$kind.$area
    elif [ "$area" == "-1" ]; then
        mtdname=$kind
    else
        mtdname=$area
    fi

    local mtdnum=`find_mtdnum $mtdname`

    local mtdblk="/dev/mtdblock$mtdnum"
    local mmcblk=

    if [ "$mtdnum" = "" ]; then
        echo "  ! MTD \"$mtdname\" not found."
        cleanup $dir
        exit 1
    fi

    if [ "$erase" = "1" ]; then
        # MTD
        echo -n "  writing \"$kind\" image to /dev/mtd$mtdnum ... "
        flashcp $dir/$kind.img /dev/mtd$mtdnum &> /dev/null
        res=$?
    fi

    if [ "$res" != "0" ]; then
        echo "failed."
        exit 1
    else
        echo "succeeded."
    fi
}

MNTPOINT=$1
AREA=$2

if [ -f ${MNTPOINT}/at91bootstrap.bin.img ]; then
    echo "* AT91Bootstrap file found."
    write_to_mtd ${MNTPOINT} at91bootstrap.bin at91boot 1
fi

${MNTPOINT}/msp430_ctrl check_version ${REQ_VERSION} &> /dev/null
if [ "$?" != "0" ]; then
    echo "MSP430 needs to be programmed."
    ${MNTPOINT}/msp430_writer -f ${MNTPOINT}/msp430firm.txt
else
    echo "MSP430 is not need to update firmware."
fi
